summaryrefslogtreecommitdiffstats
path: root/libkpimexchange/core/exchangeaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkpimexchange/core/exchangeaccount.h')
-rw-r--r--libkpimexchange/core/exchangeaccount.h60
1 files changed, 30 insertions, 30 deletions
diff --git a/libkpimexchange/core/exchangeaccount.h b/libkpimexchange/core/exchangeaccount.h
index 505232c8..244fc944 100644
--- a/libkpimexchange/core/exchangeaccount.h
+++ b/libkpimexchange/core/exchangeaccount.h
@@ -23,8 +23,8 @@
#ifndef EXCHANGE_ACCOUNT_H
#define EXCHANGE_ACCOUNT_H
-#include <qobject.h>
-#include <qstring.h>
+#include <tqobject.h>
+#include <tqstring.h>
#include <kdepimmacros.h>
#include <kurl.h>
@@ -36,58 +36,58 @@ class KDE_EXPORT ExchangeAccount : public QObject
{
Q_OBJECT
public:
- ExchangeAccount( const QString &host, const QString &port,
- const QString &account, const QString &password,
- const QString &mailbox = QString::null );
+ ExchangeAccount( const TQString &host, const TQString &port,
+ const TQString &account, const TQString &password,
+ const TQString &mailbox = TQString::null );
/**
Create a new account object, read data from group app data
*/
- ExchangeAccount( const QString &group );
+ ExchangeAccount( const TQString &group );
~ExchangeAccount();
- void save( QString const &group );
- void load( QString const &group );
+ void save( TQString const &group );
+ void load( TQString const &group );
- QString host() { return mHost; }
- QString port() { return mPort; }
- QString account() { return mAccount; }
- QString mailbox() { return mMailbox; }
- QString password() { return mPassword; }
+ TQString host() { return mHost; }
+ TQString port() { return mPort; }
+ TQString account() { return mAccount; }
+ TQString mailbox() { return mMailbox; }
+ TQString password() { return mPassword; }
- void setHost( QString host ) { mHost = host; }
- void setPort( QString port ) { mPort = port; }
- void setAccount( QString account ) { mAccount = account; }
- void setMailbox( QString mailbox ) { mMailbox = mailbox; }
- void setPassword( QString password ) { mPassword = password; }
+ void setHost( TQString host ) { mHost = host; }
+ void setPort( TQString port ) { mPort = port; }
+ void setAccount( TQString account ) { mAccount = account; }
+ void setMailbox( TQString mailbox ) { mMailbox = mailbox; }
+ void setPassword( TQString password ) { mPassword = password; }
KURL baseURL();
KURL calendarURL();
- // Returns the mailbox URL of this user. QString::null if unsuccessful
- static QString tryFindMailbox( const QString &host, const QString &port,
- const QString &user,
- const QString &password );
+ // Returns the mailbox URL of this user. TQString::null if unsuccessful
+ static TQString tryFindMailbox( const TQString &host, const TQString &port,
+ const TQString &user,
+ const TQString &password );
// Put authentication info in KDE password store for auto-authentication
// with later webdav access. Also calculates the calendar URL.
bool authenticate();
- bool authenticate( QWidget *window );
+ bool authenticate( TQWidget *window );
private:
bool authenticate( int windowId );
void calcFolderURLs();
- static QString tryMailbox( const QString &_url, const QString &user,
- const QString &password );
+ static TQString tryMailbox( const TQString &_url, const TQString &user,
+ const TQString &password );
private slots:
void slotFolderResult( KIO::Job * );
private:
- QString mHost;
- QString mPort;
- QString mAccount;
- QString mMailbox;
- QString mPassword;
+ TQString mHost;
+ TQString mPort;
+ TQString mAccount;
+ TQString mMailbox;
+ TQString mPassword;
KURL *mCalendarURL;
bool mError;